Crate kcr_org_eclipse_che

Crate kcr_org_eclipse_che 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the org.eclipse.che group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

org.eclipse.che/v1

  • CheCluster

org.eclipse.che/v2

  • CheCluster

Modules

v1
v2