CheClusterSpec

Struct CheClusterSpec 

pub struct CheClusterSpec {
    pub auth: Option<CheClusterAuth>,
    pub dashboard: Option<CheClusterDashboard>,
    pub database: Option<CheClusterDatabase>,
    pub dev_workspace: Option<CheClusterDevWorkspace>,
    pub git_services: Option<CheClusterGitServices>,
    pub image_puller: Option<CheClusterImagePuller>,
    pub k8s: Option<CheClusterK8s>,
    pub metrics: Option<CheClusterMetrics>,
    pub server: Option<CheClusterServer>,
    pub storage: Option<CheClusterStorage>,
}
Desired configuration of the Che installation. Based on these settings, the Operator automatically creates and maintains several ConfigMaps that will contain the appropriate environment variables the various components of the Che installation. These generated ConfigMaps must NOT be updated manually.

Fields

auth: Option<CheClusterAuth>

Configuration settings related to the Authentication used by the Che installation.

dashboard: Option<CheClusterDashboard>

Configuration settings related to the User Dashboard used by the Che installation.

database: Option<CheClusterDatabase>

Configuration settings related to the database used by the Che installation.

dev_workspace: Option<CheClusterDevWorkspace>

DevWorkspace operator configuration

git_services: Option<CheClusterGitServices>

A configuration that allows users to work with remote Git repositories.

image_puller: Option<CheClusterImagePuller>

Kubernetes Image Puller configuration

k8s: Option<CheClusterK8s>

Configuration settings specific to Che installations made on upstream Kubernetes.

metrics: Option<CheClusterMetrics>

Configuration settings related to the metrics collection used by the Che installation.

server: Option<CheClusterServer>

General configuration settings related to the Che server, the plugin and devfile registries

storage: Option<CheClusterStorage>

Configuration settings related to the persistent storage used by the Che installation.