pub struct CheClusterComponentsDevfileRegistryDeploymentSecurityContext {
pub fs_group: Option<i64>,
pub run_as_user: Option<i64>,
}Expand description
Security options the pod should run with.
Fields
fs_group: Option<i64>A special supplemental group that applies to all containers in a pod. The default value is 1724.
run_as_user: Option<i64>The UID to run the entrypoint of the container process. The default value is 1724.