pub struct CheClusterComponentsPluginRegistryDeploymentContainersResourcesRequest {
pub cpu: Option<IntOrString>,
pub memory: Option<IntOrString>,
}Expand description
Describes the minimum amount of compute resources required.
Fields
cpu: Option<IntOrString>CPU, in cores. (500m = .5 cores)
If the value is not specified, then the default value is set depending on the component.
If value is 0, then no value is set for the component.
memory: Option<IntOrString>Memory, in bytes. (500Gi = 500GiB = 500 * 1024 * 1024 * 1024)
If the value is not specified, then the default value is set depending on the component.
If value is 0, then no value is set for the component.