pub struct CheClusterDevEnvironmentsDefaultComponentsCustom {
pub component_class: String,
pub embedded_resource: BTreeMap<String, Value>,
}Expand description
Custom component whose logic is implementation-dependant and should be provided by the user possibly through some dedicated controller
Fields
component_class: StringClass of component that the associated implementation controller should use to process this command with the appropriate logic
embedded_resource: BTreeMap<String, Value>Additional free-form configuration for this custom component that the implementation controller will know how to use