CheClusterDevEnvironmentsDefaultComponentsPlugin

Struct CheClusterDevEnvironmentsDefaultComponentsPlugin 

pub struct CheClusterDevEnvironmentsDefaultComponentsPlugin {
    pub commands: Option<Vec<CheClusterDevEnvironmentsDefaultComponentsPluginCommands>>,
    pub components: Option<Vec<CheClusterDevEnvironmentsDefaultComponentsPluginComponents>>,
    pub id: Option<String>,
    pub import_reference_type: Option<CheClusterDevEnvironmentsDefaultComponentsPluginImportReferenceType>,
    pub kubernetes: Option<CheClusterDevEnvironmentsDefaultComponentsPluginKubernetes>,
    pub registry_url: Option<String>,
    pub uri: Option<String>,
    pub version: Option<String>,
}
Allows importing a plugin.

Plugins are mainly imported devfiles that contribute components, commands and events as a consistent single unit. They are defined in either YAML files following the devfile syntax, or as DevWorkspaceTemplate Kubernetes Custom Resources

Fields

commands: Option<Vec<CheClusterDevEnvironmentsDefaultComponentsPluginCommands>>

Overrides of commands encapsulated in a parent devfile or a plugin. Overriding is done according to K8S strategic merge patch standard rules.

components: Option<Vec<CheClusterDevEnvironmentsDefaultComponentsPluginComponents>>

Overrides of components encapsulated in a parent devfile or a plugin. Overriding is done according to K8S strategic merge patch standard rules.

id: Option<String>

Id in a registry that contains a Devfile yaml file

import_reference_type: Option<CheClusterDevEnvironmentsDefaultComponentsPluginImportReferenceType>

type of location from where the referenced template structure should be retrieved

kubernetes: Option<CheClusterDevEnvironmentsDefaultComponentsPluginKubernetes>

Reference to a Kubernetes CRD of type DevWorkspaceTemplate

registry_url: Option<String>

Registry URL to pull the parent devfile from when using id in the parent reference. To ensure the parent devfile gets resolved consistently in different environments, it is recommended to always specify the registryUrl when id is used.

uri: Option<String>

URI Reference of a parent devfile YAML file. It can be a full URL or a relative URI with the current devfile as the base URI.

version: Option<String>

Specific stack/sample version to pull the parent devfile from, when using id in the parent reference. To specify version, id must be defined and used as the import reference source. version can be either a specific stack version, or latest. If no version specified, default version will be used.