pub struct CheClusterDevEnvironmentsDefaultNamespace {
pub auto_provision: Option<bool>,
pub template: Option<String>,
}Expand description
User’s default namespace.
Fields
auto_provision: Option<bool>Indicates if is allowed to automatically create a user namespace. If it set to false, then user namespace must be pre-created by a cluster administrator.
template: Option<String>If you don’t create the user namespaces in advance, this field defines the Kubernetes namespace created when you start your first workspace.
You can use <username> and <userid> placeholders, such as che-workspace-