This crate contains kube-rs compatible bindings for Kubernetes custom resources for the org.eclipse.che group. Each binding is generated with kopium, updated and released weekly.
org.eclipse.che
CheCluster