pub struct CheClusterServerDevfileRegistryRoute {
pub annotations: Option<BTreeMap<String, String>>,
pub domain: Option<String>,
pub labels: Option<String>,
}Expand description
Deprecated. The value of this flag is ignored. The devfile registry route custom settings.
Fields
annotations: Option<BTreeMap<String, String>>Unstructured key value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata.
domain: Option<String>Operator uses the domain to generate a hostname for a route.
In a conjunction with labels it creates a route, which is served by a non-default Ingress controller.
The generated host name will follow this pattern: <route-name>-<route-namespace>.<domain>.
labels: Option<String>Comma separated list of labels that can be used to organize and categorize objects by scoping and selecting.