pub struct CheClusterDevEnvironmentsDefaultComponentsPluginComponentsContainerEndpoints {
pub annotation: Option<BTreeMap<String, String>>,
pub attributes: Option<BTreeMap<String, Value>>,
pub exposure: Option<CheClusterDevEnvironmentsDefaultComponentsPluginComponentsContainerEndpointsExposure>,
pub name: String,
pub path: Option<String>,
pub protocol: Option<CheClusterDevEnvironmentsDefaultComponentsPluginComponentsContainerEndpointsProtocol>,
pub secure: Option<bool>,
pub target_port: Option<i64>,
}Fields
annotation: Option<BTreeMap<String, String>>Annotations to be added to Kubernetes Ingress or Openshift Route
attributes: Option<BTreeMap<String, Value>>Map of implementation-dependant string-based free-form attributes.
Examples of Che-specific attributes:
-
cookiesAuthEnabled: “true” / “false”,
-
type: “terminal” / “ide” / “ide-dev”,
exposure: Option<CheClusterDevEnvironmentsDefaultComponentsPluginComponentsContainerEndpointsExposure>Describes how the endpoint should be exposed on the network.
-
publicmeans that the endpoint will be exposed on the public network, typically through a K8S ingress or an OpenShift route. -
internalmeans that the endpoint will be exposed internally outside of the main devworkspace POD, typically by K8S services, to be consumed by other elements running on the same cloud internal network. -
nonemeans that the endpoint will not be exposed and will only be accessible inside the main devworkspace POD, on a local address.
Default value is public
name: Stringpath: Option<String>Path of the endpoint URL
protocol: Option<CheClusterDevEnvironmentsDefaultComponentsPluginComponentsContainerEndpointsProtocol>Describes the application and transport protocols of the traffic that will go through this endpoint.
-
http: Endpoint will havehttptraffic, typically on a TCP connection. It will be automaticaly promoted tohttpswhen thesecurefield is set totrue. -
https: Endpoint will havehttpstraffic, typically on a TCP connection. -
ws: Endpoint will havewstraffic, typically on a TCP connection. It will be automaticaly promoted towsswhen thesecurefield is set totrue. -
wss: Endpoint will havewsstraffic, typically on a TCP connection. -
tcp: Endpoint will have traffic on a TCP connection, without specifying an application protocol. -
udp: Endpoint will have traffic on an UDP connection, without specifying an application protocol.
Default value is http
secure: Option<bool>Describes whether the endpoint should be secured and protected by some
authentication process. This requires a protocol of https or wss.
target_port: Option<i64>Port number to be used within the container component. The same port cannot be used by two different container components.